@@ -2,5 +2,7 @@ pub mod cli_opts;
 mod commands;
 mod config;
 
+pub use commands::build::build;
 pub use commands::dev::dev;
 pub use commands::serve::serve;
+mod build_util;
